:html_theme.sidebar_secondary.remove: true
:html_theme.sidebar_primary.remove: true

.. _radiosim:

========
radiosim
========


.. currentmodule:: radiosim

|

**Version**: |version| | **Date**: |today|

**Useful links**:
`Source Repository <https://github.com/radionets-project/radiosim>`__ |
`Issue Tracker <https://github.com/radionets-project/radiosim/issues>`__ |
`Pull Requests <https://github.com/radionets-project/radiosim/pulls>`__

**License**: `MIT <https://github.com/radionets-project/radiosim/blob/main/LICENSE>`__

**Python**: |python_requires|

Simulation of radio skies to create astrophysical data sets. This repository is part of the
`Radionets Project <https://github.com/radionets-project>`__.


.. _radiosim_docs:

.. toctree::
  :maxdepth: 1
  :hidden:

  user-guide/index
  developer-guide/index
  api-reference/index
  changelog
  glossary



.. grid:: 1 2 2 3

    .. grid-item-card::
        :class-item: animated-sd-card

        :octicon:`book;40px`

        User Guide
        ^^^^^^^^^^

        Learn how to get started as a user. This guide
        will help you install radiosim.

        +++

        .. button-ref:: user-guide/index
            :expand:
            :color: primary
            :click-parent:

            To the user guide


    .. grid-item-card::
        :class-item: animated-sd-card

        :octicon:`person-add;40px`

        Developer Guide
        ^^^^^^^^^^^^^^^

        Learn how to get started as a developer.
        This guide will help you install radiosim for development
        and explains how to contribute.

        +++

        .. button-ref:: developer-guide/index
            :expand:
            :color: primary
            :click-parent:

            To the developer guide


    .. grid-item-card::
        :class-item: animated-sd-card

        :octicon:`code;40px`

        API Docs
        ^^^^^^^^

        The API docs contain detailed descriptions of
        of the various modules, classes and functions
        included in radiosim.

        +++

        .. button-ref:: api-reference/index
            :expand:
            :color: primary
            :click-parent:

            To the API docs
